close abstract method

Future<void> close()

Closes this stream and releases any system resources associated with it. If the stream is already closed then invoking this method has no effect.

As noted in {@link AutoCloseable#close()}, cases where the close may fail require careful attention. It is strongly advised to relinquish the underlying resources and to internally mark the {@code Closeable} as closed, prior to throwing the {@code IOException}.

Implementation

Future<void> close();