InterruptibleChannel class abstract interface

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Tells whether or not this channel is open.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Closes this stream and releases any system resources associated with it. If the stream is already closed then invoking this method has no effect.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited