LockedDock class

Inheritance

Constructors

LockedDock()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDeparture(Departure outgo) bool
Add outgoing ship to the waiting queue
inherited
assembleArrival(Arrival income) Arrival?
Check received ship for completed package
inherited
checkResponse(Arrival response) Departure?
Check response from incoming ship
inherited
createArrivalHall() ArrivalHall
inherited
createDepartureHall() DepartureHall
inherited
getNextDeparture(DateTime now) Departure?
Get next new/timeout task
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purge([DateTime? now]) int
Clear all expired tasks
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

halfMinute → const Duration