Star Ship
Container carrying data package
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sn → dynamic
-
Get ID for this Ship
no setter
Methods
-
getStatus(
DateTime now) → ShipStatus - Check ship state
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
touch(
DateTime now) → void - Update sent time
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited